/*
 * $Id$
 *
 * z3ctrl - Control the Sanyo Z3 Projector via Remote Management
 *
 * Copyright (c) 2005 by Harald Klein <hari@vt100.at>
 *
 * GPL or BSD License applies in licensee chosen version
 *
 */

#include <stdio.h>
#include <unistd.h>
#include <fcntl.h>
#include <termios.h>

#include "lcdp_sanyo_z3.h"

#define Z3CTRL_VERSION "v0.1"


int z3_send_cmd(FILE *fd, char *sendcmd) {

	char ret;
	fprintf(fd, "%s\r", sendcmd);
	ret = fgetc(fd);
	fgetc(fd); // consume carriage return
	// ? means the z3 isnt happy with our input
	if (ret=='?') { return -1; } else return 0;
}

char *z3_read_cmd(FILE *fd, char *readcmd) {
	char *resptmp = NULL;
	fprintf(fd, "%s\r", readcmd); 
	resptmp = (char *)malloc(sizeof(char)*160);
	fscanf(fd, "%s\r", &resptmp);
	return resptmp;
}

int main(int argc, char **argv)
{
    // getopt stuff
    char *serialdevice = NULL;
    int index;
    int c;

    // handle to z3
    FILE *sanyoz3 = NULL;

    // settings
    struct termios settings;
    int verbose = 0;
    int sstatus = 0;
    int ssettings = 0;
    int slamptimer = 0;
    int stemp = 0;
    int scommand = 0;
    int sinput = 0;
    int result = 0;
    char *response = NULL;
//    char *usercommand = NULL;
    char *sendcommand = NULL;

    opterr = 0;

    while ((c = getopt(argc, argv, "itlSsvhf:c:")) != -1)
	switch (c) {
	case 'h':
	    printf("Z3ctrl %s - Control your Sanyo Z3 LCD Projector via RS-232\n",Z3CTRL_VERSION);
	    printf("Copryight (c) 2005 Harald Klein <hari@vt100.at>\n\n");
	    printf("Usage:\n%s [-f device] [-h] [-v] [-s] [-S] [-l] [-t] [-c cmd]\n\n", argv[0]);
	    printf("-f device\tspecify serial port (default: /dev/lcdprojector)\n");
	    printf("-h\t\tprint out this help\n");
	    printf("-v\t\tbe verbose\n");
	    printf("-s\t\tshow status\n");
	    printf("-i\t\tshow active input\n");
	    printf("-S\t\tshow settings\n");
	    printf("-l\t\tshow lamp timer\n");
	    printf("-t\t\tshow temperature\n");
	    printf("-c cmd\t\tsend command cmd (use -c help for list)\n");
	    printf("\n");
	    exit(0);
	    break;
	case 'f':
	    serialdevice = optarg;
	    break;
	case 's':
	    sstatus = 1;
	    break;
	case 'S':
	    ssettings = 1;
	    break;
	case 'l':
	    slamptimer = 1;
	    break;
	case 'i':
	    sinput = 1;
	    break;
	case 't':
	    stemp = 1;
	    break;
	case 'c':
	    sendcommand = optarg;
	    scommand = 1;
	    break;
	case 'v':
	    verbose = 1;
	    break;
	case '?':
	    if (isprint(optopt))
		fprintf(stderr, "Unknown option `-%c'.\n", optopt);
	    else
		fprintf(stderr, "Unknown option character `\\x%x'.\n",
			optopt);
	    return 1;
	default:
	    abort();
	}

    // dump parameters
    if (verbose) {
	for (index = optind; index < argc; index++)
	    printf("Non-option argument %s\n", argv[index]);
    }

    if (scommand == 1) {
	if (strncasecmp(sendcommand, "help")==0) {
	    printf("Z3ctrl - Control your Sanyo Z3 LCD Projector via RS-232\n");
	    printf("Copryight (c) 2005 Harald Klein <hari@vt100.at>\n\n");
	    printf("Usage:\n%s [-f device] [-h] [-v] [-s] [-S] [-l] [-t] [-c cmd]\n\n", argv[0]);
	    printf("Valid [cmd] commands are:\n\n");
	    printf("\tpower_on\t\tpower up the Z3\n");
	    printf("\tpower_offq\t\tinstant power off the Z3\n");
	    printf("\tpower_off\t\tpower off the Z3\n");
	    printf("\tpower_mgmt_on\t\tenable power management\n");
	    printf("\tpower_mgmt_off\t\tdisable power management\n");
	    printf("\tmenu_on\t\t\tshow the menu\n");
	    printf("\tmenu_off\t\thide the menu\n");
	    printf("\tdisplay_mute\t\tblank the screen\n");
	    printf("\tdisplay_unmute\t\tshow the screen\n");
	    printf("\tdisplay_clear\t\tclear the screen\n");
	    printf("\tlamp_auto1\t\tset lamp to auto1 mode\n");
	    printf("\tlamp_auto2\t\tset lamp to auto2 mode\n");
	    printf("\tlamp_normal\t\tset lamp to normal mode\n");
	    printf("\tlamp_eco\t\tset lamp to eco mode\n");
	    printf("\tsize_normal\t\tnormal screen size\n");
	    printf("\tsize_full\t\tfull screen size\n");
	    printf("\tsize_zoom\t\tzoom the screen\n");
	    printf("\tsize_natural1\t\tnatural screen size 1\n");
	    printf("\tsize_natural2\t\tnatural screen size 2\n");
	    printf("\tsize_true\t\ttrue screen size\n");
	    printf("\tsize_digital\t\tdigital screen size\n");
	    printf("\tsize_caption1\t\tcaption 1 screen size\n");
	    printf("\tsize_caption2\t\tcaption 2 screen size\n");
	    printf("\tsize_full_through\tfull through screen size\n");
	    printf("\tsize_normal_through\tnormal through screen size\n");
	    printf("\timage_video\t\timage settings for video\n");
	    printf("\timage_ccinema\t\timage settings for creative cinema\n");
	    printf("\timage_pcinema\t\timage settings for pure cinema\n");
	    printf("\timage_1\t\t\timage settings for preset 1\n");
	    printf("\timage_2\t\t\timage settings for preset 2\n");
	    printf("\timage_3\t\t\timage settings for preset 3\n");
	    printf("\timage_4\t\t\timage settings for preset 4\n");
	    printf("\timage_graphic\t\timage settings for graphics\n");
	    printf("\timage_dynamic\t\timage settings for dynamic adaption\n");
	    printf("\timage_powerful\t\timage settings for powerful presentation\n");
	    printf("\timage_natural\t\timage settings for natural viewing\n");
	    printf("\tsource_video\t\tselect video source\n");
	    printf("\tsource_svideo\t\tselect s-video source\n");
	    printf("\tsource_comp1\t\tselect component source 1\n");
	    printf("\tsource_comp2\t\tselect component source 2\n");
	    printf("\tsource_computer\t\tselect computer source\n");
	    printf("\tsource_scart\t\tselect RGB (scart) source\n");
	    printf("\tsource_hdmi\t\tselect hdmi source\n");
	    printf("\tpointer_left\t\tpointer left\n");
	    printf("\tpointer_right\t\tpointer right\n");
	    printf("\tpointer_up\t\tpointer up\n");
	    printf("\tpointer_down\t\tpointer down\n");
	    printf("\tenter\t\t\tenter\n");
	    printf("\tcancel\t\t\tcancel\n");
	    printf("\tceiling_on\t\tactivate ceiling mount mode\n");
	    printf("\tceiling_off\t\tdisable set ceiling mount mode\n");
	    printf("\trear_on\t\t\tactivate rear projection mode\n");
	    printf("\trear_off\t\tdisable rear projection mode\n");
	    printf("\tfactory_reset\t\treset all settings to factory defaults\n");
	    printf("\tkeystone_up\t\tkeystone correction increase value\n");
	    printf("\tkeystone_down\t\tkeystone correction decrease value\n");
	    printf("\tauto_adjust\t\tauto-adjust image settings for computer source\n");
	    printf("\tlogo_off\t\terase logo\n");
	    printf("\tlogo_default\t\tuse default logo\n");
	    printf("\tlogo_user\t\tuse user supplied logo\n");
	    printf("\tlogo_capture\t\tcapture user supplied logo\n");
	    printf("\tlogo_on\t\t\tshow default logo\n");
	    printf("\n\n");
	    exit(0);
	}
    }
    // open serial
    if (serialdevice == NULL) {
	if (verbose)
	    printf("serialdevice = /dev/lcdprojector\n");
	if ( (sanyoz3 = fopen("/dev/lcdprojector", "r+")) == NULL) {
		perror("can't open device");
		printf("/dev/lcdprojector is not a valid device\n");
		exit( -1);
	}
    } else {
	if (verbose)
	    printf("serialdevice = %s\n", serialdevice);
	if ( (sanyoz3 = fopen(serialdevice, "r+")) == NULL) {
		perror("can't open device");
		printf("%s is not a valid device\n",serialdevice);
		exit( -1);
	}
    }

    // init serial
    result = tcgetattr(fileno(sanyoz3), &settings);
    if (result < 0) {
	perror("error in tcgetattr");
	exit( -1);
    }
    result = cfsetispeed(&settings,B19200);    
    if (result < 0) {
	perror("error in cfsetispeed");
	exit( -1);
    }
    result = cfsetospeed(&settings,B19200);    
    if (result < 0) {
	perror("error in cfsetospeed");
	exit( -1);
    }
    result = tcsetattr(fileno(sanyoz3), TCSANOW, &settings);
    if (result < 0) {
	perror("error in tcsetattr");
	exit( -1);
    }


    // read stati
    if (sstatus == 1) {
	if (verbose) printf("Reading status\n");
	response = z3_read_cmd(sanyoz3,SANYOZ3_READ_STATUS);
	if (verbose) printf("%s\n",response);
	if (strcmp(response, SANYOZ3_SC_POWER_ON)==0) printf ("STATUS POWER ON\n");
	if (strcmp(response, SANYOZ3_SC_POWER_FAILURE)==0) printf ("STATUS POWER FAILURE\n");
	if (strcmp(response, SANYOZ3_SC_POWER_SAVE)==0) printf ("STATUS POWER SAVE\n");
	if (strcmp(response, SANYOZ3_SC_PROC_COUNT_DOWN)==0) printf ("STATUS COUNT DOWN\n");
	if (strcmp(response, SANYOZ3_SC_PROC_COOL_DOWN)==0) printf ("STATUS COOL DOWN\n");
	if (strcmp(response, SANYOZ3_SC_PROC_COOL_DOWN_TEMP)==0) printf ("STATUS COOL DOWN HIGH TEMP\n");
	if (strcmp(response, SANYOZ3_SC_PROC_COOL_DOWN_PWRSV)==0) printf ("STATUS COOL DOWN POWERSAVE\n");
	if (strcmp(response, SANYOZ3_SC_RECOVER_ABNORMAL_TEMP)==0) printf ("STATUS RECOVER FROM ABNORMAL TEMP\n");
	free(response);
	response=NULL;
    }
    if (ssettings == 1) {
	if (verbose) printf("Reading settings\n");
	response = z3_read_cmd(sanyoz3,SANYOZ3_READ_SETTING);
	if (verbose) printf("%s\n",response);
	if (strcmp(response, SANYOZ3_SET_NORMAL)==0) printf ("SETTING NORMAL\n");
	if (strcmp(response, SANYOZ3_SET_MOUNT)==0) printf ("SETTING MOUNT\n");
	if (strcmp(response, SANYOZ3_SET_REAR)==0) printf ("SETTING REAR\n");
	if (strcmp(response, SANYOZ3_SET_CEILING)==0) printf ("SETTING CEILING\n");
	free(response);
	response=NULL;
    }
    if (sinput == 1) {
	if (verbose) printf("Reading active input\n");
	response = z3_read_cmd(sanyoz3,SANYOZ3_READ_INPUT);
	if (verbose) printf("%s\n",response);
	if (strcmp(response, SANYOZ3_IM_VIDEO)==0) printf ("INPUT VIDEO\n");
	if (strcmp(response, SANYOZ3_IM_SVIDEO)==0) printf ("INPUT VIDEO\n");
	if (strcmp(response, SANYOZ3_IM_COMPONENT1)==0) printf ("INPUT COMPONENT 1\n");
	if (strcmp(response, SANYOZ3_IM_COMPONENT2)==0) printf ("INPUT COMPONENT 2\n");
	if (strcmp(response, SANYOZ3_IM_HDMI)==0) printf ("INPUT HDMI\n");
	if (strcmp(response, SANYOZ3_IM_COMPUTER)==0) printf ("INPUT COMPUTER\n");
	if (strcmp(response, SANYOZ3_IM_SCART)==0) printf ("INPUT SCART\n");
	free(response);
	response=NULL;
    }
    if (slamptimer == 1) {
	if (verbose) printf("Reading lamp timer\n");
	response = z3_read_cmd(sanyoz3,SANYOZ3_READ_LAMP);
	if (verbose) printf("%s\n",response);
	printf("LAMP TIMER: %s\n",response);
	free(response);
	response=NULL;
    }
    if (stemp == 1) {
	if (verbose) printf("Reading temperature\n");
	response = z3_read_cmd(sanyoz3,SANYOZ3_READ_TEMP);
	if (verbose) printf("%s\n",response);
	printf("TEMP: %s\n",response);
	free(response);
	response=NULL;
    }
    
    // send command
    if (scommand == 1) {
	if (strncasecmp(sendcommand,"power_on")==0) {
 	    if (verbose) printf("Setting power to on\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_POWER_ON)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"power_offq")==0) {
 	    if (verbose) printf("Setting power to instant off\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_POWER_OFF_QUICK)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"power_off")==0) {
 	    if (verbose) printf("Setting power to off\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_POWER_OFF)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"power_mgmt_on")==0) {
 	    if (verbose) printf("Activating power management\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_POWERMGMT_ON)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"power_mgmt_off")==0) {
 	    if (verbose) printf("Disabling power management\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_POWERMGMT_OFF)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"menu_on")==0) {
 	    if (verbose) printf("Activating menu\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_MENU_ON)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"menu_off")==0) {
 	    if (verbose) printf("Deactivating menu\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_MENU_OFF)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"display_mute")==0) {
 	    if (verbose) printf("Disabling display\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_VIDEO_MUTE_ON)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"display_unmute")==0) {
 	    if (verbose) printf("Enabling display\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_VIDEO_MUTE_OFF)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"display_clear")==0) {
 	    if (verbose) printf("Clear display\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_DISPLAY_CLEAR)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"lamp_auto1")==0) {
 	    if (verbose) printf("Set lamp mode to auto1\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_LAMP_AUTO1)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"lamp_auto2")==0) {
 	    if (verbose) printf("Set lamp mode to auto2\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_LAMP_AUTO2)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"lamp_normal")==0) {
 	    if (verbose) printf("Set lamp mode to normal\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_LAMP_NORMAL)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"lamp_eco")==0) {
 	    if (verbose) printf("Set lamp mode to eco\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_LAMP_ECO)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"size_normal")==0) {
 	    if (verbose) printf("Set screen size to normal\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_SCREEN_SIZE_NORMAL)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"size_full")==0) {
 	    if (verbose) printf("Set screen size to full\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_SCREEN_SIZE_FULL)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"size_zoom")==0) {
 	    if (verbose) printf("Set screen size to zoom\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_SCREEN_SIZE_ZOOM)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"size_natural1")==0) {
 	    if (verbose) printf("Set screen size to natural preset 1\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_SCREEN_SIZE_NATURAL1)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"size_natural2")==0) {
 	    if (verbose) printf("Set screen size to natural preset 2\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_SCREEN_SIZE_NATURAL2)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"size_true")==0) {
 	    if (verbose) printf("Set screen size to true\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_SCREEN_SIZE_TRUE)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"size_digital")==0) {
 	    if (verbose) printf("Set screen size to digital\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_SCREEN_SIZE_DIGITAL)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"size_caption1")==0) {
 	    if (verbose) printf("Set screen size to caption 1\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_SCREEN_SIZE_CAPTION1)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"size_caption2")==0) {
 	    if (verbose) printf("Set screen size to caption 2\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_SCREEN_SIZE_CAPTION2)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"size_full_through")==0) {
 	    if (verbose) printf("Set screen size to full through\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_SCREEN_SIZE_FULL_THROUGH)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"size_normal_through")==0) {
 	    if (verbose) printf("Set screen size to normal through\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_SCREEN_SIZE_NORMAL_THROUGH)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"image_video")==0) {
 	    if (verbose) printf("Set image settings to video\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_IMAGE_VIDEO)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"image_ccinema")==0) {
 	    if (verbose) printf("Set image settings to creative cinema\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_IMAGE_CCINEMA)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"image_pcinema")==0) {
 	    if (verbose) printf("Set image settings to pure cinema\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_IMAGE_PCINEMA)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"image_1")==0) {
 	    if (verbose) printf("Set image settings to preset 1\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_IMAGE_1)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"image_2")==0) {
 	    if (verbose) printf("Set image settings to preset 2\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_IMAGE_2)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"image_3")==0) {
 	    if (verbose) printf("Set image settings to preset 3\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_IMAGE_3)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"image_4")==0) {
 	    if (verbose) printf("Set image settings to preset 4\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_IMAGE_4)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"image_graphic")==0) {
 	    if (verbose) printf("Set image settings to graphic\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_IMAGE_GRAPHIC)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"image_dynamic")==0) {
 	    if (verbose) printf("Set image settings to dynamic\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_IMAGE_DYNAMIC)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"image_powerful")==0) {
 	    if (verbose) printf("Set image settings to powerful\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_IMAGE_POWERFUL)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"image_natural")==0) {
 	    if (verbose) printf("Set image settings to natural\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_IMAGE_NATURAL)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"source_video")==0) {
 	    if (verbose) printf("Set input source to video\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_SOURCE_VIDEO)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"source_svideo")==0) {
 	    if (verbose) printf("Set input source to s-video\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_SOURCE_SVIDEO)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"source_comp1")==0) {
 	    if (verbose) printf("Set input source to component 1\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_SOURCE_COMPONENT1)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"source_comp2")==0) {
 	    if (verbose) printf("Set input source to component 2\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_SOURCE_COMPONENT2)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"source_computer")==0) {
 	    if (verbose) printf("Set input source to computer\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_SOURCE_COMPUTER)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"source_scart")==0) {
 	    if (verbose) printf("Set input source to RGB Scart\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_SOURCE_SCART)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"source_hdmi")==0) {
 	    if (verbose) printf("Set input source to hdmi\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_SOURCE_VIDEO)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"pointer_left")==0) {
 	    if (verbose) printf("Move pointer left\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_POINTER_LEFT)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"pointer_right")==0) {
 	    if (verbose) printf("Move pointer right\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_POINTER_RIGHT)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"pointer_up")==0) {
 	    if (verbose) printf("Move pointer up\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_POINTER_UP)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"pointer_down")==0) {
 	    if (verbose) printf("Move pointer down\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_POINTER_DOWN)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"enter")==0) {
 	    if (verbose) printf("Enter\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_ENTER)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"cancel")==0) {
 	    if (verbose) printf("Cancel\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_CANCEL)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"ceiling_on")==0) {
 	    if (verbose) printf("Configure for ceiling mount\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_CEILING_ON)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"ceiling_off")==0) {
 	    if (verbose) printf("Disable ceiling mount\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_CEILING_OFF)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"rear_on")==0) {
 	    if (verbose) printf("Configure for rear projection\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_REAR_ON)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"rear_off")==0) {
 	    if (verbose) printf("Disable rear projection\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_REAR_OFF)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"factory_reset")==0) {
 	    if (verbose) printf("Factory Reset\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_FACTORY_RESET)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"keystone_up")==0) {
 	    if (verbose) printf("Increase keystone\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_KEYSTONE_UP)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"keystone_down")==0) {
 	    if (verbose) printf("Decrease keystone\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_KEYSTONE_DOWN)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"auto_adjust")==0) {
 	    if (verbose) printf("Auto adjust computer input\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_AUTO_PC_ADJUST)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"logo_off")==0) {
 	    if (verbose) printf("Disable logo\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_LOGO_OFF)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"logo_default")==0) {
 	    if (verbose) printf("Use default logo\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_LOGO_DEFAULT)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"logo_user")==0) {
 	    if (verbose) printf("Use user supplied logo\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_LOGO_USER)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"logo_capture")==0) {
 	    if (verbose) printf("Capture logo\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_LOGO_CAPTURE)!=0) { printf("communication error!\n"); exit(1); }
	}
	if (strncasecmp(sendcommand,"logo_on")==0) {
 	    if (verbose) printf("Show default logo\n");
	    if (z3_send_cmd(sanyoz3, SANYOZ3_CMD_LOGO_PICTURE_ON)!=0) { printf("communication error!\n"); exit(1); }
	}
    }
//    response = (char *) malloc(sizeof(char)*200);
    
//    fprintf(sanyoz3,"%s\r",SANYOZ3_READ_STATUS);

    if (sanyoz3 != NULL)
	fclose(sanyoz3);
    return 0;
}

/*
 * $Log$
 *
 */
